===================
Authors and Credits
===================

If we have neglected to include you, please let us know right away!

* `Kyle Barbary <https://github.com/kbarbary>`_
* `Larry Bradley <https://github.com/larrybradley>`_
* `Matt Craig <https://github.com/mwcraig>`_
* `Christoph Deil <https://github.com/cdeil>`_
* `Mike DiPompeo <https://github.com/mdipompe>`_
* `Demitri Muna <https://github.com/demitri>`_
* `Thomas Robitaille <https://github.com/astrofrog>`_
* `Erik Tollerud <https://github.com/eteq>`_
* `Benjamin Alan Weaver <https://github.com/weaverba137>`_
* `Kyle Westfall <https://github.com/kbwestfall>`_
